==> jena-5.2.0-source-release.zip: jena-5.2.0/jena-fuseki2/jena-fuseki-main/src/test/java/org/apache/jena/fuseki/main/access/TestSimpleBearer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.fuseki.main.access;

import static org.junit.Assert.*;

import org.apache.jena.fuseki.main.auth.SimpleBearer;
import org.junit.Test;

public class TestSimpleBearer {

    private static String USERNAME = "BlackAdder";

    @Test public void simple_bearer_token() {
        String x = SimpleBearer.requestAuthorizationToken(USERNAME);
        assertFalse(x.startsWith("Bearer "));
        // No variant of base64 has ":"
        assertFalse(x.contains(":"));
        String user = SimpleBearer.getUserFromToken64(x);
        assertEquals(USERNAME, user);
    }

    @Test public void simple_bearer_header() {
        String x = SimpleBearer.requestAuthorizationHeader(USERNAME);
        assertTrue(x.startsWith("Bearer "));
        String y = x.replaceFirst("^Bearer *", "");
        // No variant of base64 has ":"
        assertFalse(y.contains(":"));
        String user = SimpleBearer.getUserFromAuthHeader(x);
        assertEquals(USERNAME, user);
    }
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-fuseki2/jena-fuseki-main/src/test/java/org/apache/jena/fuseki/main/access/TestSimpleBearer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.fuseki.main.access;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

import org.apache.jena.fuseki.main.auth.SimpleBearer;

public class TestSimpleBearer {

    private static String USERNAME = "BlackAdder";

    @Test public void simple_bearer_token() {
        String x = SimpleBearer.requestAuthorizationToken(USERNAME);
        assertFalse(x.startsWith("Bearer "));
        // No variant of base64 has ":"
        assertFalse(x.contains(":"));
        String user = SimpleBearer.getUserFromToken64(x);
        assertEquals(USERNAME, user);
    }

    @Test public void simple_bearer_header() {
        String x = SimpleBearer.requestAuthorizationHeader(USERNAME);
        assertTrue(x.startsWith("Bearer "));
        String y = x.replaceFirst("^Bearer *", "");
        // No variant of base64 has ":"
        assertFalse(y.contains(":"));
        String user = SimpleBearer.getUserFromAuthHeader(x);
        assertEquals(USERNAME, user);
    }
}
